pub struct OembedPlugin;Expand description
Plugin that emits per-page oEmbed 1.0 documents plus the discovery
<link> tag.
Examples
use ssg::oembed::OembedPlugin;
use ssg::plugin::Plugin;
assert_eq!(OembedPlugin::default().name(), "oembed");Trait Implementations
Sourceimpl Clone for OembedPlugin
impl Clone for OembedPlugin
Sourcefn clone(&self) -> OembedPlugin
fn clone(&self) -> OembedPlugin
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OembedPlugin
Sourceimpl Debug for OembedPlugin
impl Debug for OembedPlugin
Sourceimpl Default for OembedPlugin
impl Default for OembedPlugin
Sourcefn default() -> OembedPlugin
fn default() -> OembedPlugin
Returns the “default value” for a type. Read more
Sourceimpl Plugin for OembedPlugin
impl Plugin for OembedPlugin
Sourcefn transform_html(
&self,
html: &str,
path: &Path,
ctx: &PluginContext,
) -> Result<String, SsgError>
fn transform_html( &self, html: &str, path: &Path, ctx: &PluginContext, ) -> Result<String, SsgError>
Injects the oEmbed discovery <link> before </head> when the
page’s *.oembed.json sibling exists. Idempotent.
Sourcefn after_compile(&self, ctx: &PluginContext) -> Result<(), SsgError>
fn after_compile(&self, ctx: &PluginContext) -> Result<(), SsgError>
Called after site compilation completes. Read more
Sourcefn has_transform(&self) -> bool
fn has_transform(&self) -> bool
Returns
true if this plugin implements transform_html.
Override to true to opt in to the fused transform pass.Sourcefn before_compile(&self, _ctx: &PluginContext) -> Result<(), SsgError>
fn before_compile(&self, _ctx: &PluginContext) -> Result<(), SsgError>
Called before site compilation begins. Read more
Sourcefn needs_all_files(&self) -> bool
fn needs_all_files(&self) -> bool
Returns
true if this plugin must always observe the full
cache.html_files() list — even during --incremental
rebuilds that only invalidated a handful of pages. Read moreAuto Trait Implementations
impl Freeze for OembedPlugin
impl RefUnwindSafe for OembedPlugin
impl Send for OembedPlugin
impl Sync for OembedPlugin
impl Unpin for OembedPlugin
impl UnsafeUnpin for OembedPlugin
impl UnwindSafe for OembedPlugin